close all
clear

% We want to display the Bezier curve c defined by the control points
% b_i stored in the rows of the matrix B:

B = [-1, 1;
      0, 0;
      1, 1 ];
  
% We have three control points, hence c is a quadratic curve. We use
% Matlab's spmak function to build a polynomial curve in Bezier form:

c = spmak([0 0 0 1 1 1], B');

% Evaluate the curve c in B-form using spval at the paramter values
% stored in t:

t = linspace(0, 1, 50);
p = spval(c, t);

% Control points, as well as function values as stored in the COLUMNS 
% of a matrix!

plot(p(1,:), p(2,:));

axis equal
hold on

% Plot the control polygon in red

plot(B(:,1), B(:,2), '-ro');

%--------------------------------------------------------------------

% Lets try a 3D example for a cubic curve. We need 4 control points:

B = [0, 0, 0;
     1, 0, 0;
     0, 1, 0;
     0, 0, 1 ];
 
% The so called 'knot' sequence is always a sequence of degree+1 zeros
% followed by degree+1 ones for a Bezier curve:

c = spmak([0 0 0 0 1 1 1 1], B');
t = linspace(0, 1, 50);
p = spval(c, t);

figure;

plot3(p(1,:), p(2,:), p(3,:));

axis equal
axis vis3d
hold on

rotate3d

% Plot the control polygon in red

plot3(B(:,1), B(:,2), B(:, 3), '-ro');

%--------------------------------------------------------------------

% spcol computes the collocation matrix, i.e., given parameter values t
% it evaluates all Bernstein polynomials of given degree at those values 
% and returns the result as a matrix of size (length(t), degree+1). We
% need to provide the 'knot' sequence as explained above, degree+1, and
% the vector t of parameter values:

C = spcol([0 0 0 0 1 1 1 1], 4, t);

% Given control points in the matrix B we can use the result to evaluate
% the corresponding curve (as an alternative to using spval):

Y = C*B;

plot3(Y(:,1), Y(:,2), Y(:,3), 'g.');
